==> huaweicloudsdkservicestage-3.1.54-py2.py3-none-any.whl: huaweicloudsdkservicestage/v2/model/list_commits_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListCommitsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'commits': 'list[CommitsCommits]'
    }

    attribute_map = {
        'commits': 'commits'
    }

    def __init__(self, commits=None):
        """ListCommitsResponse

        The model defined in huaweicloud sdk

        :param commits: 提交记录列表。
        :type commits: list[:class:`huaweicloudsdkservicestage.v2.CommitsCommits`]
        """
        
        super(ListCommitsResponse, self).__init__()

        self._commits = None
        self.discriminator = None

        if commits is not None:
            self.commits = commits

    @property
    def commits(self):
        """Gets the commits of this ListCommitsResponse.

        提交记录列表。

        :return: The commits of this ListCommitsResponse.
        :rtype: list[:class:`huaweicloudsdkservicestage.v2.CommitsCommits`]
        """
        return self._commits

    @commits.setter
    def commits(self, commits):
        """Sets the commits of this ListCommitsResponse.

        提交记录列表。

        :param commits: The commits of this ListCommitsResponse.
        :type commits: list[:class:`huaweicloudsdkservicestage.v2.CommitsCommits`]
        """
        self._commits = commits

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListCommitsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkservicestage-3.1.144-py2.py3-none-any.whl: huaweicloudsdkservicestage/v2/model/list_commits_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListCommitsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'commits': 'list[CommitsCommits]'
    }

    attribute_map = {
        'commits': 'commits'
    }

    def __init__(self, commits=None):
        r"""ListCommitsResponse

        The model defined in huaweicloud sdk

        :param commits: 提交记录列表。
        :type commits: list[:class:`huaweicloudsdkservicestage.v2.CommitsCommits`]
        """
        
        super(ListCommitsResponse, self).__init__()

        self._commits = None
        self.discriminator = None

        if commits is not None:
            self.commits = commits

    @property
    def commits(self):
        r"""Gets the commits of this ListCommitsResponse.

        提交记录列表。

        :return: The commits of this ListCommitsResponse.
        :rtype: list[:class:`huaweicloudsdkservicestage.v2.CommitsCommits`]
        """
        return self._commits

    @commits.setter
    def commits(self, commits):
        r"""Sets the commits of this ListCommitsResponse.

        提交记录列表。

        :param commits: The commits of this ListCommitsResponse.
        :type commits: list[:class:`huaweicloudsdkservicestage.v2.CommitsCommits`]
        """
        self._commits = commits

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListCommitsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
